#!/usr/bin/env python3
#--------------------------------------------------------------#
# Script to extract water depths at observation points
#--------------------------------------------------------------#
import sys
import xarray as xr
import numpy as np
import scipy.interpolate
import matplotlib.pyplot as plt
import matplotlib.cm as cm
#--------------------------------------------------------------#
# Create center line
pt1 = [936158.0, 527243.2]
pt2 = [936237.0, 527218.2]
pt3 = [936260.4, 527174.6]

nPts = 200
xCen1 = np.linspace(pt1[0],pt2[0],nPts)
xCen2 = np.linspace(pt2[0],pt3[0],nPts)
yCen1 = np.linspace(pt1[1],pt2[1],nPts)
yCen2 = np.linspace(pt2[1],pt3[1],nPts)

xCen = np.concatenate((xCen1,xCen2))
yCen = np.concatenate((yCen1,yCen2))

legend = ['Without turbine','With 1 twin','With 2 twin']

#--------------------------------------------------------------#
## Read from command line
nArgv = len(sys.argv)
if nArgv <= 1:
    cases = ['0xTwinTurbineSys','1xTwinTurbineSys','2xTwinTurbineSys']
    nArgv = len(cases)
else:
    cases = sys.argv[1:]
    nArgv -= 1

plt.figure()
## Extract data
for iF in range(0,nArgv):
    # Get map file data:
    file=cases[iF]+'/DFM_OUTPUT_FlowFM/FlowFM_map.nc'

    ds = xr.open_dataset(file)
    nLayers = ds.mesh2d_nLayers

    velX = np.array(ds.mesh2d_ucx)[-1]
    velY = np.array(ds.mesh2d_ucy)[-1]
    vel = np.sqrt(velX**2 + velY**2)

    xcoords = np.array(ds.mesh2d_face_x)
    ycoords = np.array(ds.mesh2d_face_y)
    waterLevel = np.array(ds.mesh2d_s1[-1])
    bl = np.array(ds.mesh2d_flowelem_bl)
    waterDepth = waterLevel

    s = np.sqrt((xCen-xCen[0])**2 + (yCen-yCen[0])**2)

    wdInterp = scipy.interpolate.griddata((xcoords,ycoords),waterDepth,(xCen,yCen))
    plt.plot(s,wdInterp,label=legend[iF])

blInterp = scipy.interpolate.griddata((xcoords,ycoords),bl,(xCen,yCen))

## Plotting
plt.plot(s, blInterp, label='Bed Level')
plt.xlabel('Distance (m)')
plt.ylabel('Water Level (m)')
plt.tight_layout()
plt.legend()
plt.show()

